atomate.lammps package — atomate 0.3 documentation

# atomate.lammps package

## Subpackages

- atomate.lammps.firetasks package
  - Submodules
  - atomate.lammps.firetasks.parse_outputs module
  - atomate.lammps.firetasks.run_calc module
  - atomate.lammps.firetasks.write_inputs module
  - Module contents
- atomate.lammps.workflows package
  - Submodules
  - atomate.lammps.workflows.core module
  - atomate.lammps.workflows.presets module
  - Module contents

## Submodules

## atomate.lammps.database module

class `atomate.lammps.database.` `MMLammpsDb`(host=u'localhost', port=27017, database=u'lammps', collection=u'tasks', user=None, password=None)

  Bases: `atomate.utils.database.MMDb`

  `__init__`(host=u'localhost', port=27017, database=u'lammps', collection=u'tasks', user=None, password=None)
  `build_indexes`(indexes=None, background=True)
  `reset`()

## Module contents